<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>ShowAllLayers</name>
    <message>
        <source>&amp;Show all Layers</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Pokaż wszystkie warstwy</translation>
    </message>
</context>
<context>
    <name>UnlockAllLayers</name>
    <message>
        <location filename="../UnlockAllLayersInit.js" line="+2"/>
        <source>&amp;Unlock All Layers</source>
        <translation>&amp;Odblokuj wszystkie warstwy</translation>
    </message>
</context>
</TS>
